//
//  TimeBlockView.swift
//  SplatoonWhatsPlaying
//

import Cocoa

class SplatfestThreeRegularView : NSView {
    init (regular_m: [String]) {
        assert(regular_m.count == 3)
        
        super.init(frame:NSZeroRect)
        
        translatesAutoresizingMaskIntoConstraints = false
        setContentCompressionResistancePriority(NSLayoutPriorityDefaultHigh, for: .vertical)
        setContentCompressionResistancePriority(NSLayoutPriorityDefaultHigh, for: .horizontal)
        setContentHuggingPriority(NSLayoutPriorityDefaultHigh, for: .vertical)
        setContentHuggingPriority(NSLayoutPriorityDefaultHigh, for: .horizontal)
        
        let boldFont = NSFont.boldSystemFont(ofSize: NSFont.smallSystemFontSize())
        let regularFont = NSFont.systemFont(ofSize: NSFont.smallSystemFontSize())
        
        //let pink = NSColor(colorLiteralRed: 251.0/255.0, green: 153.0/255.0, blue: 218.0, alpha: 1.0)
        
        // Nintendo website uses #fb9400 for orange, equal to (251, 148, 0)
        let orange = NSColor(colorLiteralRed: 251.0/255.0, green: 148.0/255.0, blue: 0.0, alpha: 1.0)
        
        let regularColor = orange
        
        let t1 = NSTextField()
        t1.stringValue = "Splatfest"
        t1.isEditable = false
        t1.font = boldFont
        t1.textColor = regularColor
        t1.isBordered = false
        t1.drawsBackground = false
        t1.translatesAutoresizingMaskIntoConstraints = false
        addSubview(t1)
        
        let i1 = NSImageView()
        i1.image = NSImage(named:regular_m[0])
        i1.addConstraint(NSLayoutConstraint(item: i1, attribute: .height, relatedBy: .equal, toItem: i1, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i1.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i1)
        
        let i2 = NSImageView()
        i2.image = NSImage(named:regular_m[1])
        i2.addConstraint(NSLayoutConstraint(item: i2, attribute: .height, relatedBy: .equal, toItem: i2, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i2.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i2)
        
        let c1 = NSTextField()
        c1.stringValue = regular_m[0]
        c1.isEditable = false
        c1.font = regularFont
        c1.alignment = .center
        c1.textColor = regularColor
        c1.isBordered = false
        c1.drawsBackground = false
        c1.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c1)
        
        let c2 = NSTextField()
        c2.stringValue = regular_m[1]
        c2.isEditable = false
        c2.font = regularFont
        c2.alignment = .center
        c2.textColor = regularColor
        c2.isBordered = false
        c2.drawsBackground = false
        c2.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c2)
        
        let i3 = NSImageView()
        i3.image = NSImage(named:regular_m[2])
        i3.addConstraint(NSLayoutConstraint(item: i3, attribute: .height, relatedBy: .equal, toItem: i3, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i3.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i3)
        
        let c3 = NSTextField()
        c3.stringValue = regular_m[2]
        c3.isEditable = false
        c3.font = regularFont
        c3.alignment = .center
        c3.textColor = regularColor
        c3.isBordered = false
        c3.drawsBackground = false
        c3.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c3)
        
        let views = ["v": self, "t1": t1, "i1": i1, "i2": i2, "c1": c1, "c2": c2, "i3": i3, "c3": c3]
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "H:|[t1]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "H:|[i1]-[i2]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "V:|[t1][i1][c1][i3][c3]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "V:|[t1][i2][c2][i3][c3]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraint(NSLayoutConstraint(item: i1, attribute: .leading, relatedBy: .equal, toItem: c1, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i1, attribute: .trailing, relatedBy: .equal, toItem: c1, attribute: .trailing, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i2, attribute: .leading, relatedBy: .equal, toItem: c2, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i2, attribute: .trailing, relatedBy: .equal, toItem: c2, attribute: .trailing, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i3, attribute: .leading, relatedBy: .equal, toItem: c3, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i3, attribute: .trailing, relatedBy: .equal, toItem: c3, attribute: .trailing, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i3, attribute: .width, relatedBy: .equal, toItem: i1, attribute: .width, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i3, attribute: .width, relatedBy: .equal, toItem: i2, attribute: .width, multiplier: 1, constant: 0))
        // see https://github.com/evgenyneu/center-vfl
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "V:[v]-(<=1)-[i3]", options: .alignAllCenterX, metrics: nil, views: views))
    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
}
