//
//  TimeBlockView.swift
//  SplatoonWhatsPlaying
//

import Cocoa

class TwoRegularTwoRankedView : NSView {
    var t1:NSTextField
    var i1:NSImageView
    var i2:NSImageView
    var c1:NSTextField
    var c2:NSTextField
    var t2:NSTextField
    var i3:NSImageView
    var i4:NSImageView
    var c3:NSTextField
    var c4:NSTextField

    convenience init () {
NSLog("\(Thread.isMainThread ? "(Main thread)" : "(Not main thread)") \(#function)")
        self.init(regular_m: ["blank", "blank"], ranked_m: ["blank", "blank"], ranked_r: "")
        c1.stringValue = ""
        c2.stringValue = ""
        c3.stringValue = ""
        c4.stringValue = ""
    }
    
    init (regular_m: [String], ranked_m: [String], ranked_r: String) {
NSLog("\(Thread.isMainThread ? "(Main thread)" : "(Not main thread)") \(#function)")
        assert(regular_m.count == 2)
        assert(ranked_m.count == 2)
        
        t1 = NSTextField()
        i1 = NSImageView()
        i2 = NSImageView()
        c1 = NSTextField()
        c2 = NSTextField()
        t2 = NSTextField()
        i3 = NSImageView()
        i4 = NSImageView()
        c3 = NSTextField()
        c4 = NSTextField()

        super.init(frame:NSZeroRect)
        
        translatesAutoresizingMaskIntoConstraints = false
        setContentCompressionResistancePriority(NSLayoutPriorityDefaultHigh, for: .vertical)
        setContentCompressionResistancePriority(NSLayoutPriorityDefaultHigh, for: .horizontal)
        setContentHuggingPriority(NSLayoutPriorityDefaultHigh, for: .vertical)
        setContentHuggingPriority(NSLayoutPriorityDefaultHigh, for: .horizontal)
        
        let boldFont = NSFont.boldSystemFont(ofSize: NSFont.smallSystemFontSize())
        let regularFont = NSFont.systemFont(ofSize: NSFont.smallSystemFontSize())
        
        //let pink = NSColor(colorLiteralRed: 251.0/255.0, green: 153.0/255.0, blue: 218.0, alpha: 1.0)
        //let turquoise = NSColor(colorLiteralRed: 7.0/255.0, green: 241.0/255.0, blue: 238.0, alpha: 1.0)

        // Nintendo website uses #fb9400 for orange, #0c0093 for blue, equal to (251, 148, 0) and (12, 0, 147)
        let orange = NSColor(colorLiteralRed: 251.0/255.0, green: 148.0/255.0, blue: 0.0, alpha: 1.0)
        let blue = NSColor(colorLiteralRed: 12.0/255.0, green: 0.0, blue: 147.0/255.0, alpha: 1.0)
        
        let regularColor = orange
        let rankedColor = blue
        
        t1.stringValue = "Turf War"
        t1.isEditable = false
        t1.font = boldFont
        t1.textColor = regularColor
        t1.isBordered = false
        t1.drawsBackground = false
        t1.translatesAutoresizingMaskIntoConstraints = false
        addSubview(t1)
        
        i1.image = NSImage(named:regular_m[0])
        i1.addConstraint(NSLayoutConstraint(item: i1, attribute: .height, relatedBy: .equal, toItem: i1, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i1.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i1)
        
        i2.image = NSImage(named:regular_m[1])
        i2.addConstraint(NSLayoutConstraint(item: i2, attribute: .height, relatedBy: .equal, toItem: i2, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i2.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i2)
        
        c1.stringValue = regular_m[0]
        c1.isEditable = false
        c1.font = regularFont
        c1.alignment = .center
        c1.textColor = regularColor
        c1.isBordered = false
        c1.drawsBackground = false
        c1.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c1)
        
        c2.stringValue = regular_m[1]
        c2.isEditable = false
        c2.font = regularFont
        c2.alignment = .center
        c2.textColor = regularColor
        c2.isBordered = false
        c2.drawsBackground = false
        c2.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c2)
        
        t2.stringValue = ranked_r
        t2.isEditable = false
        t2.font = boldFont
        t2.textColor = rankedColor
        t2.isBordered = false
        t2.drawsBackground = false
        t2.translatesAutoresizingMaskIntoConstraints = false
        addSubview(t2)
        
        i3.image = NSImage(named:ranked_m[0])
        i3.addConstraint(NSLayoutConstraint(item: i3, attribute: .height, relatedBy: .equal, toItem: i3, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i3.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i3)
        
        i4.image = NSImage(named:ranked_m[1])
        i4.addConstraint(NSLayoutConstraint(item: i4, attribute: .height, relatedBy: .equal, toItem: i4, attribute: .width, multiplier: (73.0/130.0), constant: 0))
        i4.translatesAutoresizingMaskIntoConstraints = false
        addSubview(i4)
        
        c3.stringValue = ranked_m[0]
        c3.isEditable = false
        c3.font = regularFont
        c3.alignment = .center
        c3.textColor = rankedColor
        c3.isBordered = false
        c3.drawsBackground = false
        c3.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c3)
        
        c4.stringValue = ranked_m[1]
        c4.isEditable = false
        c4.font = regularFont
        c4.alignment = .center
        c4.textColor = rankedColor
        c4.isBordered = false
        c4.drawsBackground = false
        c4.translatesAutoresizingMaskIntoConstraints = false
        addSubview(c4)
        
        let views = ["v": self, "t1": t1, "i1": i1, "i2": i2, "c1": c1, "c2": c2, "t2": t2, "i3": i3, "i4": i4, "c3": c3, "c4": c4] as [String : Any]
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "H:|[t1]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "H:|[i1]-[i2]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "V:|[t1][i1][c1]-[t2][i3][c3]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "V:|[t1][i2][c2]-[t2][i4][c4]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "H:|[t2]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraints(NSLayoutConstraint.constraints(withVisualFormat: "H:|[i3]-[i4]|", options: NSLayoutFormatOptions(rawValue: 0), metrics: nil, views: views))
        addConstraint(NSLayoutConstraint(item: i1, attribute: NSLayoutAttribute.leading, relatedBy: .equal, toItem: c1, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i1, attribute: NSLayoutAttribute.trailing, relatedBy: .equal, toItem: c1, attribute: .trailing, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i2, attribute: NSLayoutAttribute.leading, relatedBy: .equal, toItem: c2, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i2, attribute: NSLayoutAttribute.trailing, relatedBy: .equal, toItem: c2, attribute: .trailing, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i3, attribute: NSLayoutAttribute.leading, relatedBy: .equal, toItem: c3, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i3, attribute: NSLayoutAttribute.trailing, relatedBy: .equal, toItem: c3, attribute: .trailing, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i4, attribute: NSLayoutAttribute.leading, relatedBy: .equal, toItem: c4, attribute: .leading, multiplier: 1, constant: 0))
        addConstraint(NSLayoutConstraint(item: i4, attribute: NSLayoutAttribute.trailing, relatedBy: .equal, toItem: c4, attribute: .trailing, multiplier: 1, constant: 0))
    }
    
    func recycle (_ regular_m: [String], ranked_m: [String], ranked_r: String) {
NSLog("\(Thread.isMainThread ? "(Main thread)" : "(Not main thread)") \(#function)")
        assert(regular_m.count == 2)
        assert(ranked_m.count == 2)

        i1.image = NSImage(named:regular_m[0])
        i2.image = NSImage(named:regular_m[1])
        c1.stringValue = regular_m[0]
        c2.stringValue = regular_m[1]
        t2.stringValue = ranked_r
        i3.image = NSImage(named:ranked_m[0])
        i4.image = NSImage(named:ranked_m[1])
        c3.stringValue = ranked_m[0]
        c4.stringValue = ranked_m[1]
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
}
